# person

Source: [base_schema_pkg/base/person.k](https://url/to/source_code/base_schema_pkg/base/person.k)

## Schema Person

### Attributes

|Name and Description|Type|Default Value|Required|
|--------------------|----|-------------|--------|
|**name**|str|Undefined|**required**|
|**age**|int|Undefined|**required**|
<!-- Auto generated by kcl-doc tool, please do not edit. -->
